import type { ProxyConfiguration } from './ProxyConfiguration';
import type { SdkVerbosity } from './SdkVerbosity';
import { TrackingConsent } from './TrackingConsent';
/**
 * The SDK configuration class.
 * It will be used to configure the SDK functionality at initialization.
 */
export declare class DdSdkReactNativeConfiguration {
    readonly clientToken: string;
    readonly env: string;
    readonly applicationId: string;
    readonly trackInteractions: boolean;
    readonly trackResources: boolean;
    readonly trackErrors: boolean;
    readonly trackingConsent: TrackingConsent;
    nativeCrashReportEnabled: boolean;
    /**
     * @deprecated `sampleRate` has been replaced by `sessionSamplingRate` to avoid confusion with `resourceTracingSamplingRate` and will be removed in a future release.
     */
    sampleRate?: number;
    /**
     * Percentage of sampled RUM sessions. Range `0`-`100`.
     */
    sessionSamplingRate: number;
    /**
     * Percentage of tracing integrations for network calls between your app and your backend. Range `0`-`100`.
     */
    resourceTracingSamplingRate: number;
    site: string;
    verbosity: SdkVerbosity | undefined;
    nativeViewTracking: boolean;
    proxyConfig?: ProxyConfiguration;
    serviceName?: string;
    firstPartyHosts: string[];
    /**
     * Overrides the reported version of the app.
     * Accepted characters are alphanumerics and `_`, `-`, `:`, `.`, `/`.
     * Other special characters are converted to underscores.
     *
     * See https://docs.datadoghq.com/getting_started/tagging/#define-tags for more information on the format.
     *
     * Make sure you set it correctly, as it will have to match the one specified during the upload of your source maps and other mapping files.
     */
    version?: string;
    /**
     * Add a suffix to the reported version of the app.
     * Accepted characters are alphanumerics and `_`, `-`, `:`, `.`, `/`.
     * Other special characters are converted to underscores.
     *
     * See https://docs.datadoghq.com/getting_started/tagging/#define-tags for more information on the format.
     *
     * A dash (`-`) will be automatically added between the version and the suffix
     */
    versionSuffix?: string;
    /**
     * The sampling rate for Internal Telemetry (info related to the work of the
     * SDK internals).
     *
     * The sampling rate must be a value between 0 and 100. A value of 0 means no
     * telemetry will be sent, 100 means all telemetry will be sent. When
     * `telemetrySampleRate` is not set, the default value from the iOS and
     * Android SDK is used, which is 20.
     */
    telemetrySampleRate: number;
    additionalConfig: {
        [k: string]: any;
    };
    constructor(clientToken: string, env: string, applicationId: string, trackInteractions?: boolean, trackResources?: boolean, trackErrors?: boolean, trackingConsent?: TrackingConsent);
}
/**
 * Auto Instrumentation configuration passed to DatadogProvider.
 * Does not include default values.
 */
export declare type AutoInstrumentationConfiguration = {
    readonly trackInteractions: boolean;
    readonly trackResources: boolean;
    readonly firstPartyHosts?: string[];
    readonly resourceTracingSamplingRate?: number;
    readonly trackErrors: boolean;
};
/**
 * Parameters needed to start auto instrumentation. Includes default values.
 */
export declare type AutoInstrumentationParameters = {
    readonly trackInteractions: boolean;
    readonly trackResources: boolean;
    readonly firstPartyHosts: string[];
    readonly resourceTracingSamplingRate: number;
    readonly trackErrors: boolean;
};
/**
 * We could use `Proxy` instead of this function, but `Proxy` is not available on
 * the older android jsc that can still be used.
 */
export declare const addDefaultValuesToAutoInstrumentationConfiguration: (features: AutoInstrumentationConfiguration) => AutoInstrumentationParameters;
export declare type PartialInitializationConfiguration = {
    readonly clientToken: string;
    readonly env: string;
    readonly applicationId: string;
    readonly sessionSamplingRate?: number;
    readonly site?: string;
    readonly verbosity?: SdkVerbosity | undefined;
    readonly nativeViewTracking?: boolean;
    readonly proxyConfig?: ProxyConfiguration;
    readonly serviceName?: string;
    readonly version?: string;
    versionSuffix?: string;
    readonly additionalConfig?: {
        [k: string]: any;
    };
    readonly trackingConsent?: TrackingConsent;
    readonly nativeCrashReportEnabled?: boolean;
    readonly telemetrySampleRate?: number;
};
export declare const buildConfigurationFromPartialConfiguration: (features: AutoInstrumentationConfiguration, configuration: PartialInitializationConfiguration) => DdSdkReactNativeConfiguration;
export declare class DatadogProviderConfiguration extends DdSdkReactNativeConfiguration {
    initializationMode: InitializationMode;
}
export declare enum InitializationMode {
    SYNC = "SYNC",
    ASYNC = "ASYNC"
}
